reflector_nodes

Function reflector_nodes 

pub(crate) async fn reflector_nodes(
    __arg0: State<PgPool>,
    __arg1: Path<String>,
) -> Result<Json<Vec<ConnectedNodeView>>, StatusCode>
GET /api/reflectors/{callsign}/nodes — nodes linked to a reflector.

Returns the roster of gateways and hotspots currently linked to the reflector’s modules as reported by the most recent Tier 2 monitor snapshot. Entries are ordered by last_heard DESC NULLS LAST.